@@ -14,17 +14,14 @@ module Data.Monoid.Textual (
    )
 where
 
-import Prelude hiding (all, any, break, concatMap, dropWhile, foldl, foldl1, foldr, foldr1, map, scanl, scanl1, scanr, scanr1,
-                       span, takeWhile)
-
 import qualified Data.Foldable as Foldable
 import qualified Data.Traversable as Traversable
-import Data.Functor ((<$>))
+import Data.Functor -- ((<$>))
 import qualified Data.List as List
 import qualified Data.Text as Text
 import qualified Data.Text.Lazy as LazyText
 import Data.Text (Text)
-import Data.Monoid (Monoid(mappend, mempty))
+import Data.Monoid -- (Monoid(mappend, mempty))
 import qualified Data.Sequence as Sequence
 import qualified Data.Vector as Vector
 import Data.String (IsString(fromString))
@@ -34,6 +31,9 @@ import Data.Monoid.Cancellative (LeftReductiveMonoid, LeftGCDMonoid)
 import Data.Monoid.Factorial (FactorialMonoid)
 import qualified Data.Monoid.Factorial as Factorial
 
+import Prelude hiding (all, any, break, concatMap, dropWhile, foldl, foldl1, foldr, foldr1, map, scanl, scanl1, scanr, scanr1,
+                       span, takeWhile)
+
 -- | The 'TextualMonoid' class is an extension of 'FactorialMonoid' specialized for monoids that can contain
 -- characters. Its methods are generally equivalent to their namesake functions from "Data.List" and "Data.Text", and
 -- they satisfy the following laws:
@@ -79,8 +79,7 @@ import qualified Data.Monoid.Factorial as Factorial
 -- > uncurry (mapAccumR (,))
 -- > takeWhile (const True) (const True)
 -- > dropWhile (const False) (const False)
---
--- A minimal instance definition must implement 'splitCharacterPrefix'.
+-- > toString undefined . fromString
 
 class (IsString t, LeftReductiveMonoid t, LeftGCDMonoid t, FactorialMonoid t) => TextualMonoid t where
    -- | Contructs a new data type instance Like 'fromString', but from a 'Text' input instead of 'String'.
@@ -106,6 +105,9 @@ class (IsString t, LeftReductiveMonoid t, LeftGCDMonoid t, FactorialMonoid t) =>
    -- | Equivalent to 'List.concatMap' from "Data.List" with a @Char -> String@ function. Preserves all non-character
    -- data.
    concatMap :: (Char -> t) -> t -> t
+   -- | Returns the list of characters the monoid contains, after having the argument function convert all its
+   -- non-character factors into characters.
+   toString :: (t -> String) -> t -> String
    -- | Equivalent to 'List.any' from "Data.List". Ignores all non-character data.
    any :: (Char -> Bool) -> t -> Bool
    -- | Equivalent to 'List.all' from "Data.List". Ignores all non-character data.
@@ -187,6 +189,7 @@ class (IsString t, LeftReductiveMonoid t, LeftGCDMonoid t, FactorialMonoid t) =>
 
    map f = concatMap (singleton . f)
    concatMap f = foldr mappend (mappend . f) mempty
+   toString f = foldr (mappend . f) (:) []
    all p = foldr (const id) ((&&) . p) True
    any p = foldr (const id) ((||) . p) False
 
@@ -273,6 +276,7 @@ class (IsString t, LeftReductiveMonoid t, LeftGCDMonoid t, FactorialMonoid t) =>
    {-# INLINE break_ #-}
    {-# INLINE takeWhile_ #-}
    {-# INLINE dropWhile_ #-}
+   {-# MINIMAL splitCharacterPrefix #-}
 
 foldlChars :: TextualMonoid t => (Char -> Char -> Char) -> (t, Char) -> Char -> (t, Char)
 foldlOther :: Monoid t => (t, Char) -> t -> (t, Char)
@@ -294,6 +298,7 @@ instance TextualMonoid String where
    characterPrefix [] = Nothing
    map = List.map
    concatMap = List.concatMap
+   toString = const id
    any = List.any
    all = List.all
 
@@ -357,6 +362,7 @@ instance TextualMonoid Text where
    characterPrefix t = if Text.null t then Nothing else Just (Text.head t)
    map = Text.map
    concatMap = Text.concatMap
+   toString = const Text.unpack
    any = Text.any
    all = Text.all
 
@@ -419,6 +425,7 @@ instance TextualMonoid LazyText.Text where
    characterPrefix t = if LazyText.null t then Nothing else Just (LazyText.head t)
    map = LazyText.map
    concatMap = LazyText.concatMap
+   toString = const LazyText.unpack
    any = LazyText.any
    all = LazyText.all
 
@@ -486,6 +493,7 @@ instance TextualMonoid (Sequence.Seq Char) where
                           c Sequence.:< _ -> Just c
    map = Traversable.fmapDefault
    concatMap = Foldable.foldMap
+   toString = const Foldable.toList
    any = Foldable.any
    all = Foldable.all
 
@@ -551,6 +559,7 @@ instance TextualMonoid (Vector.Vector Char) where
    characterPrefix = (Vector.!? 0)
    map = Vector.map
    concatMap = Vector.concatMap
+   toString = const Vector.toList
    any = Vector.any
    all = Vector.all
 
